# This package is an experiment in active integration of upstream SCM with
# Fedora packaging.  It works something like this:
#
# The "pristine" source is actually a git repo (with no working checkout).
# The first step of %%prep is to check it out and switch to a "fedora" branch.
# If you need to add a patch to the server, just do it like a normal git
# operation, dump it with git-format-patch to a file in the standard naming
# format, and add a PatchN: line.  If you want to push something upstream,
# check out the master branch, pull, cherry-pick, and push.  FIXME describe
# rebasing, add convenience 'make' targets maybe.

#global gitdate 20120822
%global stable_abi 1
%global abidate 20120726

%if !0%{?abidate} || %{stable_abi}
# Released ABI versions.  Have to keep these manually in sync with the
# source because rpm is a terrible language.
%global ansic_major 0
%global ansic_minor 4
%global videodrv_major 13
%global videodrv_minor 1
%global xinput_major 18
%global xinput_minor 1
%global extension_major 7
%global extension_minor 0
%endif

%if 0%{?abidate}
# For git snapshots, use date for major and a serial number for minor
%global minor_serial 0
%global git_ansic_major %{abidate}
%global git_ansic_minor %{minor_serial}
%global git_videodrv_major %{abidate}
%global git_videodrv_minor %{minor_serial}
%global git_xinput_major %{abidate}
%global git_xinput_minor %{minor_serial}
%global git_extension_major %{abidate}
%global git_extension_minor %{minor_serial}
%endif

%global pkgname xorg-server

Summary:   X.Org X11 X server
Name:      xorg-x11-server
Version:   1.13.0
Release:   23%{?dist}
URL:       http://www.x.org
License:   MIT
Group:     User Interface/X

%if 0%{?gitdate}
# git snapshot.  to recreate, run:
# ./make-git-snapshot.sh `cat commitid`
Source0:   xorg-server-%{gitdate}.tar.xz
Source1:   make-git-snapshot.sh
Source2:   commitid
%else
Source0:   http://www.x.org/pub/individual/xserver/%{pkgname}-%{version}.tar.bz2
Source1:   gitignore
%endif

Source10:   xserver.pamd

# "useful" xvfb-run script
Source20:  http://svn.exactcode.de/t2/trunk/package/xorg/xorg-server/xvfb-run.sh

# for requires generation in drivers
Source30: xserver-sdk-abi-requires.release
Source31: xserver-sdk-abi-requires.git

Patch01: 0001-link-with-z-now.patch
Patch02: 0002-Hack-for-proper-MIT-SHM-rejection-for-ssh-forwarded-.patch
Patch03: 0003-Don-t-build-the-ACPI-code.patch
Patch04: 0004-RANDR-right-of-placement-by-default.patch
Patch05: 0005-Enable-PAM-support.patch
Patch06: 0006-modes-Combine-xf86DefaultModes-and-DMTModes.patch
Patch09: 0009-Re-add-nr-command-line-option-for-gdm-compatibility.patch
Patch11: 0011-xfree86-Lid-status-hack.patch
Patch14: 0014-vbe-Only-interpret-complete-failure-as-DDC-unsupport.patch
Patch15: 0015-dri2-bootstrapping-hack.patch
Patch16: 0016-build-the-touch-test-only-when-building-Xorg.patch
# Bug 858005 - Mouse jumps to edges / corners when using an absolute input
# device (ie virtual machine usb tablet)
Patch17: 0017-dix-set-the-device-transformation-matrix.patch

# fix dri1 regression
Patch18: 0001-dri1-fix-dri1-startup-since-459c6da0f907ba33d733c7e6.patch
# Bug 863913 - Grabbing a disabled device crashes the server
Patch19: 0019-dix-fix-crash-on-XI-1.x-grabs-on-disabled-devices.-5.patch
Patch20: 0020-dix-fix-crash-on-shutdown-if-a-disabled-device-is-st.patch
# Bug 864054 - Export API update_desktop_dimensions()
Patch21: 0021-xfree86-add-xf86UpdateDesktopDimensions.patch
# Bug 868054 - Regression: screen crossing for non-Xinerama setups is broken
Patch22: 0022-dix-fix-zaphod-screen-scrossing-54654.patch
# Bug 883206 - running xrestop crashes the server.
Patch23: 0001-server-fix-resources-and-compat-output-issues.patch
# Bug 879632 - excessive mieq backtraces
Patch24: 0001-mieq-Bump-default-queue-size-to-512.patch

# Bug 887759 - indirect rendering broken
Patch25: 0001-glx-dri2-initialise-api-to-avoid-indirect-rendering-.patch

# Bug 893295 - server crashes randomly on exit
Patch26: 0001-randr-cleanup-provider-properly.patch

# bug 969538 - restore glx in Xvfb
Patch27: 0001-vfb-Initialize-the-GLX-extension-again.patch

# bug 915202 - make Xephyr resizable
# RHEL mustard: do so by default; don't just blindly drop this patch
Patch28: 0001-ephyr-Add-resizeable-option.patch

Patch30: 0070-dix-pre-scale-relative-events-from-abs-devices-to-de.patch
Patch31: 0071-dix-pre-scale-x-by-the-screen-device-resolution-rati.patch
Patch32: 0072-dix-fix-device-scaling-to-use-a-min-max-range.patch
Patch33: 0073-dix-scale-y-back-instead-of-x-up-when-pre-scaling-co.patch

# Bug 795858 -  X server crashes with segfault at startup when using xfs
Patch34: 0001-fonts-Fix-xinerama-logic-better.patch

# Bug 999965 - Display freezes when using menu on wacom tablet
Patch35: 0001-dix-only-allow-button-and-key-events-to-freeze-a-syn.patch
Patch36: 0002-include-change-grabtypes-to-start-at-1.patch
Patch37: 0003-dix-don-t-attempt-to-deliver-an-event-for-a-differen.patch
Patch38: 0004-dix-only-deliver-for-the-current-grab-type.patch

# Bug 1004241 - Sometimes xorg doubles the mouse coordinates for abs input
# device with multi-card multi-screen setup
Patch39: 0001-dix-when-scaling-from-desktop-coord-take-the-total-d.patch
# Bug 991077 - Erratic mouse pointer behaviour in Xephyr with multiple screens
Patch40: 0002-Xext-pass-the-current-screen-to-miProcessDeviceEvent.patch
Patch41: 0003-Xext-if-a-root-window-is-given-in-XTestFakeInput-mov.patch
Patch42: 0001-Fix-Xephyr-compilation-when-DEBUG-is-enabled.patch
Patch43: 0002-kdrive-modify-ephyr-events-to-use-POINTER_DESKTOP-an.patch
Patch44: 0003-kdrive-fix-cursor-jumps-on-CursorOffScreen-behavior.patch

# Bug 1016854 - regression: Xorg -configure stopped working
Patch45: 0001-xf86AddBusDeviceToConfigure-Store-device-in-DevToCon.patch
# Bug 950438 - CVE-2013-1940 xorg-x11-server: Information
# disclosure due enabling events from hot-plug devices despite input from
# the device being momentarily disabled
Patch46: 0001-xf86-fix-flush-input-to-work-with-Linux-evdev-device.patch
# Bug 1014561 - CVE-2013-4396 xorg-x11-server: use-after-free flaw when handling ImageText requests
Patch47: 0001-Avoid-use-after-free-in-dix-dixfonts.c-doImageText-C.patch

# bug 919165: Xdamage does not work with Xinerama
Patch48: 0001-damage-Must-translate-initial-window-damage-by-windo.patch
Patch49: 0002-dix-Add-PostDispatchCallback.patch
Patch50: 0003-damageext-Xineramify-v4.5.patch

# Bug 1018405: Xephyr with 8bits depth color crashes when resized
Patch51: 0001-ephyr-Fix-crash-on-24bpp-host-framebuffer.patch
Patch52: 0002-ephyr-hostx_screen_init-Fix-bits_per_pixel-and-bytes.patch
patch53: 0003-ephyr-Ensure-stride-of-private-framebuffer-is-multip.patch
patch54: 0004-ephyr-Add-notresizeable-option-to-make-windows-non-r.patch

%global moduledir	%{_libdir}/xorg/modules
%global drimoduledir	%{_libdir}/dri
%global sdkdir		%{_includedir}/xorg

%ifarch s390 s390x
%global with_hw_servers 0
%else
%global with_hw_servers 1
%endif

%if %{with_hw_servers}
%global enable_xorg --enable-xorg
%else
%global enable_xorg --disable-xorg
%endif

%global kdrive --enable-kdrive --enable-xephyr --disable-xfake --disable-xfbdev
%global xservers --enable-xvfb --enable-xnest %{kdrive} %{enable_xorg}

BuildRequires: systemtap-sdt-devel
BuildRequires: git-core
BuildRequires: automake autoconf libtool pkgconfig
BuildRequires: xorg-x11-util-macros >= 1.1.5

BuildRequires: xorg-x11-proto-devel >= 7.6-20
BuildRequires: xorg-x11-font-utils >= 7.2-11

BuildRequires: xorg-x11-xtrans-devel >= 1.2.2-1
BuildRequires: libXfont-devel libXau-devel libxkbfile-devel libXres-devel
BuildRequires: libfontenc-devel libXtst-devel libXdmcp-devel
BuildRequires: libX11-devel libXext-devel
BuildRequires: libXinerama-devel libXi-devel

# DMX config utils buildreqs.
BuildRequires: libXt-devel libdmx-devel libXmu-devel libXrender-devel
BuildRequires: libXi-devel libXpm-devel libXaw-devel libXfixes-devel

# Broken, this is global, should be Xephyr-only
BuildRequires: libXv-devel

BuildRequires: pixman-devel >= 0.21.8
BuildRequires: libpciaccess-devel >= 0.12.901-1 openssl-devel byacc flex
BuildRequires: mesa-libGL-devel >= 7.6-0.6
# XXX silly...
BuildRequires: libdrm-devel >= 2.4.0 kernel-headers

BuildRequires: audit-libs-devel libselinux-devel >= 2.0.86-1
BuildRequires: hal-devel dbus-devel
BuildRequires: pam-devel

# All server subpackages have a virtual provide for the name of the server
# they deliver.  The Xorg one is versioned, the others are intentionally
# unversioned.

%description
X.Org X11 X server

%package common
Summary: Xorg server common files
Group: User Interface/X
Requires: pixman >= 0.21.8
Requires: libselinux >= 2.0.79-1
Requires: xkeyboard-config xkbcomp

%description common
Common files shared among all X servers.

%if %{with_hw_servers}
%package Xorg
Summary: Xorg X server
Group: User Interface/X
Provides: Xorg = %{version}-%{release}
Provides: Xserver
%if !0%{?gitdate} || %{stable_abi}
Provides: xserver-abi(ansic-%{ansic_major}) = %{ansic_minor}
Provides: xserver-abi(videodrv-%{videodrv_major}) = %{videodrv_minor}
Provides: xserver-abi(xinput-%{xinput_major}) = %{xinput_minor}
Provides: xserver-abi(extension-%{extension_major}) = %{extension_minor}
%endif
%if 0%{?abidate}
Provides: xserver-abi(ansic-%{git_ansic_major}) = %{git_ansic_minor}
Provides: xserver-abi(videodrv-%{git_videodrv_major}) = %{git_videodrv_minor}
Provides: xserver-abi(xinput-%{git_xinput_major}) = %{git_xinput_minor}
Provides: xserver-abi(extension-%{git_extension_major}) = %{git_extension_minor}
%endif

%ifarch %{ix86} x86_64
Requires: xorg-x11-drv-vesa
%else
Requires: xorg-x11-drv-fbdev
%endif
Requires: xorg-x11-drv-void xorg-x11-drv-evdev >= 2.1.0-3
Requires: xorg-x11-server-common >= %{version}-%{release}
Requires: libdrm >= 2.4.20
Requires: fedora-setup-keyboard
# Force sufficiently new libpciaccess
Conflicts: libpciaccess < 0.10.6-1
# Force sufficiently new gnome-screensaver
Conflicts: gnome-screensaver < 2.28.3-15
# Force synaptics driver without scaling
Conflicts: xorg-x11-drv-synaptics < 1.6.2-13

%description Xorg
X.org X11 is an open source implementation of the X Window System.  It
provides the basic low level functionality which full fledged
graphical user interfaces (GUIs) such as GNOME and KDE are designed
upon.
%endif


%package Xnest
Summary: A nested server.
Group: User Interface/X
Obsoletes: xorg-x11-Xnest
Requires: xorg-x11-server-common >= %{version}-%{release}
Provides: Xnest

%description Xnest
Xnest is an X server, which has been implemented as an ordinary
X application.  It runs in a window just like other X applications,
but it is an X server itself in which you can run other software.  It
is a very useful tool for developers who wish to test their
applications without running them on their real X server.

%package Xdmx
Summary: Distributed Multihead X Server and utilities
Group: User Interface/X
Obsoletes: xorg-x11-Xdmx
Requires: xorg-x11-server-common >= %{version}-%{release}
Provides: Xdmx

%description Xdmx
Xdmx is proxy X server that provides multi-head support for multiple displays
attached to different machines (each of which is running a typical X server).
When Xinerama is used with Xdmx, the multiple displays on multiple machines
are presented to the user as a single unified screen.  A simple application
for Xdmx would be to provide multi-head support using two desktop machines,
each of which has a single display device attached to it.  A complex
application for Xdmx would be to unify a 4 by 4 grid of 1280x1024 displays
(each attached to one of 16 computers) into a unified 5120x4096 display.

%package Xvfb
Summary: A X Windows System virtual framebuffer X server.
Group: User Interface/X
# xvfb-run is GPLv2, rest is MIT
License: MIT and GPLv2
Obsoletes: xorg-x11-Xvfb
Requires: xorg-x11-server-common >= %{version}-%{release}
# required for xvfb-run
Requires: xorg-x11-xauth
Provides: Xvfb

%description Xvfb
Xvfb (X Virtual Frame Buffer) is an X server that is able to run on
machines with no display hardware and no physical input devices.
Xvfb simulates a dumb framebuffer using virtual memory.  Xvfb does
not open any devices, but behaves otherwise as an X display.  Xvfb
is normally used for testing servers.


%package Xephyr
Summary: A nested server.
Group: User Interface/X
Requires: xorg-x11-server-common >= %{version}-%{release}
Provides: Xephyr

%description Xephyr
Xephyr is an X server, which has been implemented as an ordinary
X application.  It runs in a window just like other X applications,
but it is an X server itself in which you can run other software.  It
is a very useful tool for developers who wish to test their
applications without running them on their real X server.  Unlike
Xnest, Xephyr renders to an X image rather than relaying the
X protocol, and therefore supports the newer X extensions like
Render and Composite.


%if %{with_hw_servers}
%package devel
Summary: SDK for X server driver module development
Group: User Interface/X
Obsoletes: xorg-x11-sdk xorg-x11-server-sdk
Requires: xorg-x11-util-macros
Requires: xorg-x11-proto-devel
Requires: pkgconfig pixman-devel libpciaccess-devel
# Virtual provide for transition.  Delete me someday.
Provides: xorg-x11-server-sdk = %{version}-%{release}
# XXX doublecheck me
Provides: libxf86config = %{version}-%{release}
Obsoletes: libxf86config < 1.6.99-29
Provides: libxf86config-devel = %{version}-%{release}
Obsoletes: libxf86config-devel < 1.6.99-29


%description devel
The SDK package provides the developmental files which are necessary for
developing X server driver modules, and for compiling driver modules
outside of the standard X11 source code tree.  Developers writing video
drivers, input drivers, or other X modules should install this package.
%endif

%package source
Summary: Xserver source code required to build VNC server (Xvnc)
Group: Development/Libraries
BuildArch: noarch

%description source
Xserver source code needed to build VNC server (Xvnc)

%prep
%setup -q -n %{pkgname}-%{?gitdate:%{gitdate}}%{!?gitdate:%{version}}

%if 0%{?gitdate}
git checkout -b fedora
sed -i 's/git/&+ssh/' .git/config
if [ -z "$GIT_COMMITTER_NAME" ]; then
    git config user.email "x@fedoraproject.org"
    git config user.name "Fedora X Ninjas"
fi
%else
git init
if [ -z "$GIT_COMMITTER_NAME" ]; then
    git config user.email "x@fedoraproject.org"
    git config user.name "Fedora X Ninjas"
fi
cp %{SOURCE1} .gitignore
git add .
git commit -a -q -m "%{version} baseline."
%endif

# Apply all the patches.
#git am -p1 %{patches} < /dev/null
git am -p1 %{lua: for i, p in ipairs(patches) do print(p.." ") end} < /dev/null

%if %{with_hw_servers} && 0%{?stable_abi}
# check the ABI in the source against what we expect.
getmajor() {
    grep -i ^#define.ABI.$1_VERSION hw/xfree86/common/xf86Module.h |
    tr '(),' '   ' | awk '{ print $4 }'
}

getminor() {
    grep -i ^#define.ABI.$1_VERSION hw/xfree86/common/xf86Module.h |
    tr '(),' '   ' | awk '{ print $5 }'
}

test `getmajor ansic` == %{ansic_major}
test `getminor ansic` == %{ansic_minor}
test `getmajor videodrv` == %{videodrv_major}
test `getminor videodrv` == %{videodrv_minor}
test `getmajor xinput` == %{xinput_major}
test `getminor xinput` == %{xinput_minor}
test `getmajor extension` == %{extension_major}
test `getminor extension` == %{extension_minor}

%endif

%build

%global default_font_path "catalogue:/etc/X11/fontpath.d,built-ins"

%if %{with_hw_servers}
%global dri_flags --with-dri-driver-path=%{drimoduledir}
%else
%global dri_flags --disable-dri
%endif

%if 0%{?rhel}
%global bodhi_flags --with-vendor-web="https://www.redhat.com/apps/support/" --with-vendor-name="Red Hat, Inc."
%endif

# --with-pie ?
autoreconf -f -v --install || exit 1
export CFLAGS="${RPM_OPT_FLAGS} -Wl,-z,relro -fno-strict-aliasing"
%configure --enable-maintainer-mode %{xservers} \
	--disable-static \
	--with-pic \
	--with-int10=x86emu \
	--with-default-font-path=%{default_font_path} \
	--with-module-dir=%{moduledir} \
	--with-builderstring="Build ID: %{name} %{version}-%{release}" \
	--with-os-name="$(hostname -s) $(uname -r)" \
	--with-xkb-output=%{_localstatedir}/lib/xkb \
	--enable-install-libxf86config \
	--enable-xselinux --enable-xcsecurity --enable-record --with-dtrace \
	--enable-config-hal \
	--disable-config-udev \
	%{dri_flags} %{?bodhi_flags} \
	${CONFIGURE}

make V=1 %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT moduledir=%{moduledir}

%if %{with_hw_servers}
rm -f $RPM_BUILD_ROOT%{_libdir}/xorg/modules/libxf8_16bpp.so
rm -rf $RPM_BUILD_ROOT%{_libdir}/xorg/modules/multimedia/
mkdir -p $RPM_BUILD_ROOT%{_libdir}/xorg/modules/{drivers,input}

# yay pam
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/pam.d
install -m 0644 %{SOURCE10} $RPM_BUILD_ROOT%{_sysconfdir}/pam.d/xserver
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/security/console.apps
touch $RPM_BUILD_ROOT%{_sysconfdir}/security/console.apps/xserver

mkdir -p $RPM_BUILD_ROOT%{_datadir}/X11/xorg.conf.d

# make sure the (empty) /etc/X11/xorg.conf.d is there, system-setup-keyboard
# relies on it more or less.
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/X11/xorg.conf.d

mkdir -p $RPM_BUILD_ROOT%{_bindir}
%if %{stable_abi}
install -m 755 %{SOURCE30} $RPM_BUILD_ROOT%{_bindir}/xserver-sdk-abi-requires
%else
sed -e s/@MAJOR@/%{gitdate}/g -e s/@MINOR@/%{minor_serial}/g %{SOURCE31} > \
    $RPM_BUILD_ROOT%{_bindir}/xserver-sdk-abi-requires
chmod 755 $RPM_BUILD_ROOT%{_bindir}/xserver-sdk-abi-requires
%endif
%endif

# xdmx (note case) was renamed because hfs+ is case-insentive, lame
ln -s %{_bindir}/dmxinfo $RPM_BUILD_ROOT%{_bindir}/xdmx

# Make the source package
%global xserver_source_dir %{_datadir}/xorg-x11-server-source
%global inst_srcdir %{buildroot}/%{xserver_source_dir}
mkdir -p %{inst_srcdir}/{Xext,xkb,GL,hw/{xquartz/bundle,xfree86/common}}
mkdir -p %{inst_srcdir}/{hw/dmx/doc,man,doc,hw/dmx/doxygen}
cp {,%{inst_srcdir}/}hw/xquartz/bundle/cpprules.in
cp {,%{inst_srcdir}/}doc/smartsched
cp {,%{inst_srcdir}/}hw/dmx/doxygen/doxygen.conf.in
cp {,%{inst_srcdir}/}xserver.ent.in
cp xkb/README.compiled %{inst_srcdir}/xkb
cp hw/xfree86/xorgconf.cpp %{inst_srcdir}/hw/xfree86

install -m 0755 %{SOURCE20} $RPM_BUILD_ROOT%{_bindir}/xvfb-run

find . -type f | egrep '.*\.(c|h|am|ac|inc|m4|h.in|pc.in|man.pre|pl|txt)$' |
xargs tar cf - | (cd %{inst_srcdir} && tar xf -)
# SLEDGEHAMMER
find %{inst_srcdir}/hw/xfree86 -name \*.c -delete

# Remove unwanted files/dirs
{
    rm -f $RPM_BUILD_ROOT%{_libdir}/X11/Options
    rm -f $RPM_BUILD_ROOT%{_bindir}/in?
    rm -f $RPM_BUILD_ROOT%{_bindir}/ioport
    rm -f $RPM_BUILD_ROOT%{_bindir}/out?
    rm -f $RPM_BUILD_ROOT%{_bindir}/pcitweak
    rm -f $RPM_BUILD_ROOT%{_mandir}/man1/pcitweak.1*
    find $RPM_BUILD_ROOT -type f -name '*.la' | xargs rm -f -- || :
%if !%{with_hw_servers}
    rm -f $RPM_BUILD_ROOT%{_libdir}/pkgconfig/xorg-server.pc
    rm -f $RPM_BUILD_ROOT%{_datadir}/aclocal/xorg-server.m4
    rm -rf $RPM_BUILD_ROOT%{_defaultdocdir}/xorg-server
%endif
}

%clean
rm -rf $RPM_BUILD_ROOT


%files common
%defattr(-,root,root,-)
%doc COPYING
%{_mandir}/man1/Xserver.1*
%{_libdir}/xorg/protocol.txt
%dir %{_localstatedir}/lib/xkb
%{_localstatedir}/lib/xkb/README.compiled


%if %{with_hw_servers}
%files Xorg
%defattr(-,root,root,-)
%config %attr(0644,root,root) %{_sysconfdir}/pam.d/xserver
%config(missingok) /etc/security/console.apps/xserver
%{_bindir}/X
%attr(4755, root, root) %{_bindir}/Xorg
%{_bindir}/cvt
%{_bindir}/gtf
%dir %{_libdir}/xorg
%dir %{_libdir}/xorg/modules
%dir %{_libdir}/xorg/modules/drivers
%dir %{_libdir}/xorg/modules/extensions
%{_libdir}/xorg/modules/extensions/libglx.so
%dir %{_libdir}/xorg/modules/input
%{_libdir}/xorg/modules/libfbdevhw.so
%{_libdir}/xorg/modules/libexa.so
%{_libdir}/xorg/modules/libfb.so
%{_libdir}/xorg/modules/libint10.so
%{_libdir}/xorg/modules/libshadow.so
%{_libdir}/xorg/modules/libshadowfb.so
%{_libdir}/xorg/modules/libvbe.so
%{_libdir}/xorg/modules/libvgahw.so
%{_libdir}/xorg/modules/libwfb.so
%{_mandir}/man1/gtf.1*
%{_mandir}/man1/Xorg.1*
%{_mandir}/man1/cvt.1*
%{_mandir}/man4/fbdevhw.4*
%{_mandir}/man4/exa.4*
%{_mandir}/man5/xorg.conf.5*
%{_mandir}/man5/xorg.conf.d.5*
%dir %{_sysconfdir}/X11/xorg.conf.d
%dir %{_datadir}/X11/xorg.conf.d
%endif


%files Xnest
%defattr(-,root,root,-)
%{_bindir}/Xnest
%{_mandir}/man1/Xnest.1*

%files Xdmx
%defattr(-,root,root,-)
%{_bindir}/Xdmx
%{_bindir}/dmxaddinput
%{_bindir}/dmxaddscreen
%{_bindir}/dmxinfo
%{_bindir}/dmxreconfig
%{_bindir}/dmxresize
%{_bindir}/dmxrminput
%{_bindir}/dmxrmscreen
%{_bindir}/dmxtodmx
%{_bindir}/dmxwininfo
%{_bindir}/vdltodmx
%{_bindir}/xdmx
%{_bindir}/xdmxconfig
%{_mandir}/man1/Xdmx.1*
%{_mandir}/man1/dmxtodmx.1*
%{_mandir}/man1/vdltodmx.1*
%{_mandir}/man1/xdmxconfig.1*

%files Xvfb
%defattr(-,root,root,-)
%{_bindir}/Xvfb
%{_bindir}/xvfb-run
%{_mandir}/man1/Xvfb.1*


%files Xephyr
%defattr(-,root,root,-)
%{_bindir}/Xephyr
%{_mandir}/man1/Xephyr.1*


%if %{with_hw_servers}
%files devel
%defattr(-,root,root,-)
%doc COPYING
%{_docdir}/xorg-server
%{_bindir}/xserver-sdk-abi-requires
%{_libdir}/pkgconfig/xorg-server.pc
%dir %{_includedir}/xorg
%{sdkdir}/*.h
%{_datadir}/aclocal/xorg-server.m4
%{_libdir}/libxf86config.a
%endif


%files source
%defattr(-, root, root, -)
%{xserver_source_dir}

%changelog
* Wed Oct 23 2013 Adam Jackson <ajax@redhat.com> 1.13.0-23
- Fix root window damage reports when Xinerama is active (#919165)

* Tue Oct 22 2013 Soren Sandmann <ssp@redhat.com> 1.13.0-22
- Fix Xephyr crashes in 8 and 16 bit mode (#1018405)

* Wed Oct 09 2013 Adam Jackson <ajax@redhat.com> 1.13.0-21
- Fix Damage reports when Xinerama is active (#919165)

* Wed Oct 09 2013 Peter Hutterer <peter.hutterer@redhat.com> 1.13.0-20
- Fix broken Xorg -configure (#1016854)
- CVE-2013-1940: Fix xf86FlushInput() to drain evdev events too (#950438)
- CVE-2013-4396: Fix use-after free in ImageText requests (#1014561)

* Wed Oct 02 2013 Peter Hutterer <peter.hutterer@redhat.com> 1.13.0-19
- Fix bad mouse offset when crossing Xephyr screens (#991077)
- Fix doubling of mouse coords in multi-screen setups (#1004241)

* Thu Sep 05 2013 Peter Hutterer <peter.hutterer@redhat.com> 1.13.0-18
- Fix freeze if a proximity event is sent after a SyncPointer (#999965)

* Tue Aug 06 2013 Adam Jackson <ajax@redhat.com> 1.13.0-17
- Fix crash at startup when using a font server (#795858)

* Tue Jul 30 2013 Peter Hutterer <peter.hutterer@redhat.com> 1.13.0-16
- Conflict with older synaptics drivers to avoid bad scaling (#893808)

* Fri Jul 26 2013 Peter Hutterer <peter.hutterer@redhat.com> 1.13.0-15
- Fix uneven pointer motion for absolute devices in relative mode (#893808)

* Thu Jul 11 2013 Adam Jackson <ajax@redhat.com> 1.13.0-14
- Restore Xephyr resizability (#915202)

* Tue Jun 25 2013 Adam Jackson <ajax@redhat.com> 1.13.0-13
- Enable XC-SECURITY (#957298)

* Tue Jun 25 2013 Adam Jackson <ajax@redhat.com> 1.13.0-12
- Restore GLX in Xvfb (#969538)

* Wed Jan 09 2013 Dave Airlie <airlied@redhat.com> 1.13.0-11
- Fix misc crashes on server exit (#893295)

* Tue Dec 18 2012 Dave Airlie <airlied@redhat.com> 1.13.0-10
- Fix indirect rendering (#887759)

* Tue Dec 11 2012 Adam Jackson <ajax@redhat.com> 1.13.0-9
- Bump default mieq size (#879632)

* Wed Dec 05 2012 Dave Airlie <airlied@redhat.com> 1.13.0-8
- fix crash running xrestop (#883206)

* Wed Oct 24 2012 Peter Hutterer <peter.hutterer@redhat.com> 1.13.0-7
- Fix screen crossing for multiple ScreenRecs (xinerama off) (#868054)

* Fri Oct 12 2012 Peter Hutterer <peter.hutterer@redhat.com> 1.13.0-6
- Export xf86UpdateDesktopDimensions() for the NVIDIA driver (#864054)

* Tue Oct 09 2012 Peter Hutterer <peter.hutterer@redhat.com> 1.13.0-5
- Fix crash when grabbing disabled devices through XGrabDevice() (#863913)

* Fri Sep 28 2012 Dave Airlie <airlied@redhat.com> 1.13.0-4
- fix regression where DRI1 wasn't being initialised properly

* Thu Sep 20 2012 Peter Hutterer <peter.hutterer@redhat.com> 1.13.0-3
- Fix cursor jumping to 0/0 on absolute tablets (#858005)

* Sun Sep 09 2012 Dave Airlie <airlied@redhat.com> 1.13.0-2
- fix abidate, reported by rpmdiff

* Thu Sep 06 2012 Dave Airlie <airlied@redhat.com> 1.13.0-1
- rebase to final upstream 1.13.0 release

* Wed Aug 22 2012 Peter Hutterer <peter.hutterer@redhat.com> 1.12.99.905-2
- Improve sigsafe logging
- Fix warp pointer scaling issue resulting in wrong root coordinates
- Fix crasher on Floating devices
- Fix missing RawEvents for XI_ButtonPress implicit grabs

* Tue Aug 21 2012 Dave Airlie <airlied@redhat.com> 1.12.99.905-1
- xserver 1.13.0 RC5
- define->global,
- set ABI in stone to avoid rebuilds

* Fri Aug 17 2012 Dave Airlie <airlied@redhat.com> 1.12.99.904-2
- force ABI to be same as rc3 build

* Thu Aug 09 2012 Dave Airlie <airlied@redhat.com> 1.12.99.904-1
- xserver 1.13.0 RC4

* Tue Jul 31 2012 Adam Jackson <ajax@redhat.com> 1.12.99.903-1
- xserver 1.13.0 RC3

* Wed Mar 28 2012 Adam Jackson <ajax@redhat.com> 1.10.6-1
- xserver 1.10.6
- Use git-style patch names
- compsize.h, glxcmds.h: Copy from upstream git since they fell out of the
  upstream tarball

* Wed Mar 21 2012 Peter Hutterer <peter.hutterer@redhat.com> 1.10.4-15
- Undo regression introduced in Patch8007 (#732467)

* Mon Mar 19 2012 Adam Jackson <ajax@redhat.com> 1.10.4-14
- xserver-1.10.4-sync-revert.patch: Revert an edge-case change in IDLETIME
  that appears to be more wrong than right. (#748704)

* Mon Mar 05 2012 Adam Jackson <ajax@redhat.com> 1.10.4-13
- xserver-1.10.4-randr-corner-case.patch: Fix a corner case in initial
  mode selection. (#657580)
- xserver-1.10.4-vbe-no-cache-ddc-support.patch: Only interpret complete
  non-support for DDC extension as "DDC unavailable". (#657580)

* Fri Feb 24 2012 Peter Hutterer <peter.hutterer@redhat.com> 1.10.4-11
- xserver-1.10.4-dix-when-rescaling-from-master-rescale-from-desktop-.patch:
  fix rescaling from master to slave if the pointer (#732467)

* Thu Jan 19 2012 Peter Hutterer <peter.hutterer@redhat.com> 1.10.4-10
- Add patches to change the screen crossing behaviour for multiple
  ScreenRecs (#732467)
- remove the xorg.conf.man page from our .gitignore - we need to patch it
  now and it's part of the upstream distribution

* Tue Dec 20 2011 Adam Jackson <ajax@redhat.com> 1.10.4-9
- xserver-1.10.4-no-24bpp-xaa-composite.patch: Disable Composite at 24bpp
  in XAA (#651934)

* Wed Dec 14 2011 Adam Jackson <ajax@redhat.com> 1.10.4-8
- xserver-1.10.4-fb-picture-crash.patch: Fix crash on invalid pictures (#722680)

* Wed Nov 30 2011 Dave Airlie <airlied@redhat.com> 1.10.4-7
- fix xephyr rendering when using two screens (#757792)

* Thu Oct 20 2011 Dave Airlie <airlied@redhat.com> 1.10.4-6
- fix etracer crashes server with no modes (#746926)
- don't allow rightof with single crtc (#738724)

* Thu Oct 20 2011 Dave Airlie <airlied@redhat.com> 1.10.4-5
- coverity fixes (#741558)

* Wed Oct 12 2011 Adam Jackson <ajax@redhat.com> 1.10.4-4
- xserver-1.10.4-lid-hack.patch: Revive. (#740581)
- Conflict against older gnome-screensaver to avoid a deadlock condition
  more easily triggered with the above patch.

* Thu Sep 08 2011 Peter Hutterer <peter.hutterer@redhat.com> 1.10.4-3
- Fix server crashes when switching ScreenRecs with PointerKeys (#734969)

* Wed Sep 07 2011 Adam Jackson <ajax@redhat.com> 1.10.4-1
- xserver 1.10.4

* Mon Aug 15 2011 Adam Jackson <ajax@redhat.com> 1.10.3-5
- xserver-1.10-panning.patch: Fix RANDR CRTC panning (#655212)

* Mon Jul 25 2011 Adam Jackson <ajax@redhat.com> 1.10.3-4
- Drop multimedia/ in %%install not with %exclude

* Wed Jul 20 2011 Peter Hutterer <peter.hutterer@redhat.com> 1.10.3-3
- Fix xserver-1.10-2-xfree86-duplicate-xorg.conf-device-information-befor.patch,
  fd must be reset to -1, otherwise drivers may close the log file early.

* Wed Jul 20 2011 Peter Hutterer <peter.hutterer@redhat.com> 1.10.3-2
- xserver-1.10.3-Initialize-the-fd-to-1-for-xorg.conf-input-devices.patch:
  avoid erroneously closing the log on some drivers (e.g. wacom)

* Thu Jul 14 2011 Adam Jackson <ajax@redhat.com> 1.10.3-1
- xserver-1.7.7-lid-hack.patch: Drop, causes resume failures. (#692776)

* Thu Jul 14 2011 Adam Jackson <ajax@redhat.com> 1.10.3-0.1
- xserver 1.10.3
- xserver-1.10.1-fix-bg-set-crash.patch: Drop, 5752cc47

* Fri Jul 08 2011 Peter Hutterer <peter.hutterer@redhat.com> 1.10.2-0.7
- Fix xserver-1.10-2-xfree86-duplicate-xorg.conf-device-information-befor.patch,
  type_name must be copied and assigned to implicit devices.

* Wed Jul 06 2011 Adam Jackson <ajax@redhat.com> 1.10.2-0.6
- xserver-1.10.2-gdm-compat.patch: Fix startup compat with gdm

* Tue Jul 05 2011 Peter Hutterer <peter.hutterer@redhat.com> 1.10.2-0.5
- Three patches to fix input device-related startup crashes.

* Wed Jun 29 2011 Peter Hutterer <peter.hutterer@redhat.com> 1.10.2-0.4
- Enable HAL config backend
- Don't ship the quirks.conf file, this is in 1o-x11-input.fdi

* Tue Jun 28 2011 Adam Jackson <ajax@redhat.com> 1.10.2-0.3
- Sync xvfb-run with F15 (#693793)

* Tue Jun 28 2011 Adam Jackson <ajax@redhat.com> 1.10.2-0.2
- Add compatibility symlink from xdmx to dmxinfo
- Drop multimedia/, only used by unsupported radeon UMS

* Mon Jun 27 2011 Adam Jackson <ajax@redhat.com> 1.10.2-0.1
- Rebase baseline
